The files in `src/sorting` were derived from the **x86-simd-sort** library
(https://github.com/intel/x86-simd-sort).

Other part of **RegOT** was written by Yixuan Qiu (yixuanq@gmail.com)
and Chenrui Wang (iamwangchenrui@gmail.com).

